@@ -257,6 +257,26 @@ def get_campaign_name(googleads_client, customer_id, campaign_id):
     for batch in stream:
         for row in batch.results:
             return str(row.campaign.name)
+        
+
+def get_campaign_budget(googleads_client, customer_id, campaign_id):
+    ga_service = googleads_client.get_service("GoogleAdsService")
+    query = f"""
+            SELECT 
+                campaign_budget.amount_micros,
+                campaign.id
+                FROM campaign_budget
+            WHERE 
+                campaign.id = {campaign_id} 
+            """
+    search_request = googleads_client.get_type("SearchGoogleAdsStreamRequest")
+    search_request.customer_id = customer_id
+    search_request.query = query
+    stream = ga_service.search_stream(search_request)
+    for batch in stream:
+        for row in batch.results:
+            return float(row.campaign_budget.amount_micros) / 1000000
+        
 
 def create_keyword(googleads_client,customer_id,ad_group_id, keyword_text, kw_type,negative=False):
     ad_group_service = googleads_client.get_service("AdGroupService")
