@@ -4,7 +4,7 @@ import pandas as pd
 from datetime import datetime
 from google.ads.googleads.client import GoogleAdsClient
 from google.ads.googleads.errors import GoogleAdsException
-from autoads.keywords import get_keywords_metrics
+from autoads.keywords import get_keywords_metrics2
 from autoads.gads import create_adgroup, create_campaign, create_keyword, _handle_googleads_exception
 
 df_path = 'data/keywords_to_upload.csv' # specify keywords to uplod csv here
@@ -35,7 +35,7 @@ info_dict = {
         'type':list(),
 }
 
-df_beta = get_keywords_metrics(email, api_key, df_create, match_extract)
+df_beta = get_keywords_metrics2(email, api_key, df_create, match_extract)
 
 values = ['volume', 'cpc_exact', 'cpc_phrase']
 df_beta.loc[:,values] = df_beta.loc[:,values] / 30
@@ -44,7 +44,7 @@ df_beta['total_cost'] = df_beta['total_cost'].cumsum()
 df_beta = df_beta.sort_values(by=['total_cost'], na_position='last')
 df_beta = df_beta[df_beta['total_cost'] <= budget].reset_index(drop=True)
 
-# spendings = df_beta['total_cost'].iloc[-1]
+spendings = df_beta['total_cost'].iloc[-1]
 
 if len(df_expand) != 0:
     #code for expanding existing campaign
@@ -75,46 +75,44 @@ if len(df_expand) != 0:
         _handle_googleads_exception(ex)
 else:
     print("No keywords to add into existing campaigns")
+    
 
 # code for ceating new campaign
 if len(df_create) != 0:
     try:
-#         if spendings < budget:
-#             print('Creatinng Beta Campaigns')
-#             seed_keywords = df.groupby(['Keywords2']).groups
-#             for k, d in seed_keywords.items():
-#                 campaign = create_campaign(googleads_client, customer_id, campaignName=f'beta_{k}',
-#                                         budgetName=k+'_budget_'+f"{uuid.uuid4()}", budgetDollars=budget)
-#                 campaign_id = campaign.split('/')[-1]
-#                 data = df.iloc[d]['Keywords'].tolist()
-#                 for keyword in data:
-#                     ad_group = create_adgroup(
-#                         googleads_client, customer_id, campaign_id, adgroupName=keyword)
-#                     if ad_group is None:
-#                         continue
-#                     ad_group_id = ad_group.split('/')[-1]
-#                     keyword_id1 = create_keyword(
-#                         googleads_client, customer_id,
-#                         ad_group_id, keyword, kw_type='BROAD')
-#                     keyword_id1 = keyword_id1.split('/')[-1]
-#                     info_dict['campaign_id'].append(campaign_id)
-#                     info_dict['adgroup_id'].append(ad_group_id)
-#                     info_dict['keyword_id'].append(keyword_id1)
-#                     info_dict['keyword_id2'].append(' ')
-#                     info_dict['type'].append('created_beta')
-#             info_df = pd.DataFrame.from_dict(info_dict)
-#             df = pd.concat([df, info_df], axis=1)
-#             df.to_csv(save_path+'/beta_info.csv', index=False)
-#             print(f"{len(seed_keywords)} new campaigns created")
-        
-#         else:
-            print("Creating new Campaigns")
-            seed_keywords = df_beta.groupby(['Keywords2']).groups  
+        if spendings < budget:
+            print('Creatinng Beta Campaigns')
+            seed_keywords = df_create.groupby(['Keywords2']).groups
             for k, d in seed_keywords.items():
-                campaign = create_campaign(googleads_client,customer_id,campaignName=k,
+                campaign = create_campaign(googleads_client, customer_id, campaignName=f'beta_{k}',
                                            budgetName=k+'_budget_'+f"{uuid.uuid4()}", budgetDollars=budget)
                 campaign_id = campaign.split('/')[-1]
-                data = df_beta.iloc[d]['Keywords'].tolist()
+                data = df_create.iloc[d]['Keywords'].tolist()
+                for keyword in data:
+                    ad_group = create_adgroup(
+                        googleads_client, customer_id, campaign_id, adgroupName=keyword)
+                    if ad_group is None:
+                        continue
+                    ad_group_id = ad_group.split('/')[-1]
+                    keyword_id1 = create_keyword(
+                        googleads_client, customer_id,
+                        ad_group_id, keyword, kw_type='BROAD')
+                    keyword_id1 = keyword_id1.split('/')[-1]
+                    info_dict['campaign_id'].append(campaign_id)
+                    info_dict['adgroup_id'].append(ad_group_id)
+                    info_dict['keyword_id'].append(keyword_id1)
+                    info_dict['keyword_id2'].append(' ')
+                    info_dict['type'].append('created_beta')
+            print(f"{len(seed_keywords)} new beta campaigns created")
+        
+        elif spendings >= budget:
+            print("Creating new Campaigns")
+            seed_keywords = df_create.groupby(['Keywords2']).groups  
+            for k, d in seed_keywords.items():
+                campaign = create_campaign(googleads_client,customer_id,campaignName=k,
+                                            budgetName=k+'_budget_'+f"{uuid.uuid4()}", budgetDollars=budget)
+                campaign_id = campaign.split('/')[-1]
+                data = df_create.iloc[d]['Keywords'].tolist()
                 for keyword in data:
                     ad_group = create_adgroup(googleads_client,customer_id,campaign_id, adgroupName=keyword)
                     if ad_group is None:
@@ -141,4 +139,4 @@ else:
 
 info_df = pd.DataFrame.from_dict(info_dict)
 df = pd.concat([df, info_df], axis=1)
-df.to_csv(save_path+f'/history/{datetime.now().strftime("%m-%d-%Y %H-%M-%S")}.csv', index=False)
+df.to_csv(save_path+f'/history/{datetime.now().strftime("%m-%d-%Y %H-%M-%S")}.csv', index=False)
\ No newline at end of file
